<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Movie;

class MovieController extends Controller
{
    public function index(){
        $pageTitle = "All Movies";
        $movies = Movie::where('status', 1)->latest()->get();
        return view('admin.movies', compact('pageTitle', 'movies'));
    }
    public function updateMovie(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'type' => 'required',
            'duration' => 'required|numeric|min:0',
            'rating' => 'required|numeric|min:1',
        ]);

        if($request->id == 0){
            $movie = new Movie();
        }else{
            $movie = Movie::findOrFail($request->id);
        }

        $movie->name = $request->name;
        $movie->type = $request->type;
        $movie->duration = $request->duration;
        $movie->rating = $request->rating;
        $movie->informations = $request->informations ? $request->informations : null;
        $movie->box_office_guide = $request->box_office_guide ? $request->box_office_guide : null;
        $movie->status = 1;

        if($request->image){
            $filename = '';
            $path = imagePath()['movies']['path'];
            $size = imagePath()['movies']['size'];

            if ($request->hasFile('image')) {
                try {
                    $filename = uploadImage($request->image, $path, $size);
                } catch (\Exception $exp) {

                    $notify = 'Image could not be uploaded.';
                    return response()->json(['msg'=>$notify, 'cls'=>'error']);
                }
            }
            $movie->image = $filename;
        }

        $movie->save();

        $notify[] = ['success', 'Movie has been Updated Successfully.'];
        return back()->withNotify($notify);
    }
}
