@extends('admin.layouts.app')
@section('panel')
<div class="row mb-none-30">
  <div class="col-md-12">
    <div class="card">
        <div class="card-body p-0">
            <div class="table-responsive--sm">
                <table class="table table--light style--two">
                    <thead>
                        <tr>
                            <th scope="col">@lang('Name')</th>
                            <th scope="col">@lang('Image')</th>
                            <th scope="col">@lang('Type')</th>
                            <th scope="col">@lang('Movie Duration')</th>
                            <th scope="col">@lang('Rating')</th>
                            <th scope="col">@lang('Status')</th>
                            <th scope="col">@lang('Action')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($movies as $movie)
                        <tr>
                            <td>{{$movie->name}}</td>
                            <td data-label="@lang('Image')">
                                <img src="{{asset('assets/images/movies/'. @$movie->image)}}" class="img-fluid img-thumbnail rounded neo-shadow" style="height: 50px">
                            </td>
                            <td><span class="badge badge--primary">{{$movie->type}}</span></td>
                            <td>{{$movie->duration}} Minutes</td>
                            <td>{{$movie->rating}} STAR</td>
                            <td>
                                @if ($movie->status == 1)
                                    <span class="badge badge--success">Active</span>
                                @else
                                    <span class="badge badge--danger">Diactive</span>
                                @endif
                            </td>

                            <td>
                                <button class="btn btn-outline--primary btn-sm movieBtn"
                                    data-id="{{ $movie->id }}"
                                    data-name="{{ $movie->name }}"
                                    data-type="{{ $movie->type }}"
                                    data-duration="{{ $movie->duration }}"
                                    data-rating="{{ $movie->rating }}"
                                    data-informations="{{ $movie->informations }}"
                                    data-box_office_guide="{{ $movie->box_office_guide }}"
                                    data-status="{{ $movie->status }}"
                                    data-act="Edit">
                                    <i class="la la-pencil"></i> @lang('Edit')
                                </button>

                                {{-- @if($movie->status == 1)
                                    <button class="btn btn-sm btn-outline--danger ms-1 confirmationBtn" data-question="@lang('Are you sure to disable this plan?')" data-action="{{ route('admin.plan.status', $movie->id) }}">
                                        <i class="la la-eye-slash"></i> @lang('Disable')
                                    </button>
                                @else
                                    <button class="btn btn-sm btn-outline--success ms-1 confirmationBtn" data-question="@lang('Are you sure to enable this plan?')" data-action="{{ route('admin.plan.status', $movie->id) }}">
                                        <i class="la la-eye"></i> @lang('Enable')
                                    </button>
                                @endif --}}

                            </td>
                        </tr>
                        @empty
                        <tr>
                            <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                        </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>
  </div>
</div>

<div class="modal fade" id="planModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
            <h5 class="modal-title"><span class="act"></span> @lang('Subscription Plan')</h5>
            <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                <i class="las la-times"></i>
            </button>
            </div>
            <form action="{{ route('admin.movies.update') }}" method="post" enctype="multipart/form-data">
                @csrf
                <input type="hidden" name="id">
                <div class="modal-body">
                    <div class="form-group">
                        <label for="name">@lang('Name') </label>
                        <input type="text" class="form-control" name="name" placeholder="@lang('Movie Name')" required>
                    </div>
                    <div class="form-group">
                        <label for="details">@lang('Movie Type') </label>
                        <select name="type" class="form-control" required>
                            <option value="{{null}}"> @lang('Select Movie Type')</option>
                            <option value="Suspense">Suspense</option>
                            <option value="Crime">Crime</option>
                            <option value="Fear">Fear</option>
                            <option value="Comedy">Comedy</option>
                            <option value="Plot">Plot</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="duration">@lang('Movie Duration (In Minutes)') </label>
                        <input type="number" class="form-control" name="duration" placeholder="@lang('Movie Duration (In Minutes)')" required>
                    </div>
                    <div class="form-group">
                        <label for="details">@lang('Movie Rating') </label>
                        <select name="rating" class="form-control" required>
                            <option value="{{null}}"> @lang('Select Movie Rating')</option>
                            <option value="1">1 STAR</option>
                            <option value="2">2 STAR</option>
                            <option value="3">3 STAR</option>
                            <option value="4">4 STAR</option>
                            <option value="5">5 STAR</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="duration">@lang('Movie Informations (Optional)') </label>
                        <textarea rows="5" class="form-control" name="informations"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="duration">@lang('Box Office Guide (Optional)') </label>
                        <textarea rows="10" class="form-control" name="box_office_guide"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="image">@lang('Movie Poster') </label>
                        <div class="file-upload-wrapper" data-text="Select Movie Poster">
                            <input type="file" class="file-upload-field" name="image" id="image" placeholder="@lang('Movie Poster')">
                        </div>
                        <small class="text-secondary">Image size must be <b class="text-danger">(300x300)</b>pixel.</small>
                    </div>

                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary w-100">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>

<x-confirmation-modal />

@endsection
@push('breadcrumb-plugins')
    <button class="btn btn-outline--primary btn-sm movieBtn" data-id="0" data-act="Add" data-bs-toggle="modal" data-bs-target="#planModal"><i class="las la-plus"></i> @lang('Add New')</button>
@endpush


@push('script')
<script>
    (function($){
        "use strict";
        $('.movieBtn').on('click', function() {
            var modal = $('#planModal');
            modal.find('.act').text($(this).data('act'));
            modal.find('input[name=id]').val($(this).data('id'));
            modal.find('input[name=name]').val($(this).data('name'));
            modal.find('select[name=type]').val($(this).data('type')).change();
            modal.find('input[name=duration]').val($(this).data('duration'));
            modal.find('textarea[name=informations]').html($(this).data('informations'));
            modal.find('textarea[name=box_office_guide]').html($(this).data('box_office_guide'));
            modal.find('select[name=rating]').val($(this).data('rating')).change();
            console.log($(this).data('rating'));
            if($(this).data('id') == 0){
                modal.find('form')[0].reset();
            }
            modal.modal('show');
        });
    })(jQuery);
</script>
@endpush
