@extends('admin.layouts.app')
@section('panel')
<div class="row mb-none-30">
  <div class="col-md-12">
    <div class="card">
        <div class="card-body p-0">
            <div class="table-responsive--sm">
                <table class="table table--light style--two">
                    <thead>
                        <tr>
                            <th scope="col">@lang('Name')</th>
                            <th scope="col">@lang('Type')</th>
                            <th scope="col">@lang('Status')</th>
                            <th scope="col">@lang('Action')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($tasks as $task)
                        <tr>
                            <td>{{$task->title}}</td>
                            <td><span class="badge badge--primary">{{$task->type}}</span></td>
                            <td>
                                @if ($task->status == 1)
                                    <span class="badge badge--success">Active</span>
                                @else
                                    <span class="badge badge--danger">Diactive</span>
                                @endif
                            </td>

                            <td>
                                <button class="btn btn-outline--primary btn-sm taskBtn"
                                    data-id="{{ $task->id }}"
                                    data-title="{{ $task->title }}"
                                    data-type="{{ $task->type }}"
                                    data-condition="{{ getAmount($task->condition) }}"
                                    data-bonus="{{ getAmount($task->bonus) }}"
                                    data-status="{{ $task->status }}"
                                    data-act="Edit">
                                    <i class="la la-pencil"></i> @lang('Edit')
                                </button>
                                {{-- @if($task->status == 1)
                                    <button class="btn btn-sm btn-outline--danger ms-1 confirmationBtn" data-question="@lang('Are you sure to disable this plan?')" data-action="{{ route('admin.plan.status', $task->id) }}">
                                        <i class="la la-eye-slash"></i> @lang('Disable')
                                    </button>
                                @else
                                    <button class="btn btn-sm btn-outline--success ms-1 confirmationBtn" data-question="@lang('Are you sure to enable this plan?')" data-action="{{ route('admin.plan.status', $task->id) }}">
                                        <i class="la la-eye"></i> @lang('Enable')
                                    </button>
                                @endif --}}
                            </td>
                        </tr>
                        @empty
                        <tr>
                            <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                        </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>
  </div>
</div>

<div class="modal fade" id="planModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
            <h5 class="modal-title"><span class="act"></span> @lang('Task')</h5>
            <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                <i class="las la-times"></i>
            </button>
            </div>
            <form action="{{ route('admin.tasks.update') }}" method="post" enctype="multipart/form-data">
                @csrf
                <input type="hidden" name="id">
                <div class="modal-body">
                    <div class="form-group">
                        <label for="title">@lang('Title') </label>
                        <input type="text" class="form-control" name="title" placeholder="@lang('Enter Task Title')" required>
                    </div>
                    <div class="form-group">
                        <label for="details">@lang('Task Type') </label>
                        <select name="type" class="form-control" required>
                            <option value="{{null}}"> @lang('Select Task Type')</option>
                            <option value="deposit">Deposit Type</option>
                            <option value="refer">Refer Type</option>
                        </select>
                    </div>
                    <div class="form-group typeSection">

                    </div>
                    <div class="form-group">
                        <label for="duration">Task Bonus</label>
                        <div class="input-group">
                            <input class="form-control" type="number" step="any" name="bonus" placeholder="@lang('Task Bonus')" required>
                            <span class="input-group-text">Energy Token</span>
                        </div>
                    </div>
                </div>

                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary w-100">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>

<x-confirmation-modal />

@endsection
@push('breadcrumb-plugins')
    <button class="btn btn-outline--primary btn-sm taskBtn" data-id="0" data-act="Add" data-bs-toggle="modal" data-bs-target="#planModal"><i class="las la-plus"></i> @lang('Add New')</button>
@endpush


@push('script')

<script>
    $(document).on('change', '[name=type]', function () {
        let type = $('option:selected', this).val();
        if (type == 'deposit') {
            var html = `
            <label for="duration">Deposit Requirement</label>
            <div class="input-group">
                <input class="form-control" type="number" step="any" name="condition" placeholder="@lang('Deposit Requirement')" required>
                <span class="input-group-text">{{ __($general->cur_text) }}</span>
            </div>
            `
        }else if(type == 'refer'){
            var html = `
            <label for="duration">Refer Requirement</label>
            <div class="input-group">
                <input class="form-control" type="number" step="any" name="condition" placeholder="@lang('Refer Requirement')" required>
                <span class="input-group-text">Person</span>
            </div>
            `
        }else{
            var html = ``;
        }

        $('.typeSection').html(html);
        console.log(html);
    });
</script>

<script>
    (function($){
        "use strict";
        $('.taskBtn').on('click', function() {
            var modal = $('#planModal');
            modal.find('.act').text($(this).data('act'));
            modal.find('input[name=id]').val($(this).data('id'));
            modal.find('input[name=title]').val($(this).data('title'));
            modal.find('select[name=type]').val($(this).data('type')).change();
            modal.find('input[name=condition]').val($(this).data('condition'));
            modal.find('input[name=bonus]').val($(this).data('bonus'));
            if($(this).data('id') == 0){
                modal.find('form')[0].reset();
            }
            modal.modal('show');
        });
    })(jQuery);
</script>
@endpush
